==> chromium-browser_25.0.1364.160.orig.tar.xz: chromium-browser-25.0.1364.160/src/sync/engine/backoff_delay_provider.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_
#define SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_

#include "base/time.h"

namespace syncer {

namespace sessions {
struct ModelNeutralState;
}

// A component used to get time delays associated with exponential backoff.
class BackoffDelayProvider {
 public:
  // Factory function to create a standard BackoffDelayProvider.
  static BackoffDelayProvider* FromDefaults();

  // Similar to above, but causes sync to retry very quickly (see
  // polling_constants.h) when it encounters an error before exponential
  // backoff.
  //
  // *** NOTE *** This should only be used if kSyncShortInitialRetryOverride
  // was passed to command line.
  static BackoffDelayProvider* WithShortInitialRetryOverride();

  virtual ~BackoffDelayProvider();

  // DDOS avoidance function.  Calculates how long we should wait before trying
  // again after a failed sync attempt, where the last delay was |base_delay|.
  // TODO(tim): Look at URLRequestThrottlerEntryInterface.
  virtual base::TimeDelta GetDelay(const base::TimeDelta& last_delay);

  // Helper to calculate the initial value for exponential backoff.
  // See possible values and comments in polling_constants.h.
  virtual base::TimeDelta GetInitialDelay(
      const sessions::ModelNeutralState& state) const;

 protected:
  BackoffDelayProvider(const base::TimeDelta& default_initial_backoff,
                       const base::TimeDelta& short_initial_backoff);

 private:
  const base::TimeDelta default_initial_backoff_;
  const base::TimeDelta short_initial_backoff_;

  DISALLOW_COPY_AND_ASSIGN(BackoffDelayProvider);
};

}  // namespace syncer

#endif  // SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_

==> chromium-browser_28.0.1500.71.orig.tar.xz: chromium-browser-28.0.1500.71/src/sync/engine/backoff_delay_provider.h <==
// Copyright 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_
#define SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_

#include "base/time.h"
#include "sync/base/sync_export.h"

namespace syncer {

namespace sessions {
struct ModelNeutralState;
}

// A component used to get time delays associated with exponential backoff.
class SYNC_EXPORT_PRIVATE BackoffDelayProvider {
 public:
  // Factory function to create a standard BackoffDelayProvider.
  static BackoffDelayProvider* FromDefaults();

  // Similar to above, but causes sync to retry very quickly (see
  // polling_constants.h) when it encounters an error before exponential
  // backoff.
  //
  // *** NOTE *** This should only be used if kSyncShortInitialRetryOverride
  // was passed to command line.
  static BackoffDelayProvider* WithShortInitialRetryOverride();

  virtual ~BackoffDelayProvider();

  // DDOS avoidance function.  Calculates how long we should wait before trying
  // again after a failed sync attempt, where the last delay was |base_delay|.
  // TODO(tim): Look at URLRequestThrottlerEntryInterface.
  virtual base::TimeDelta GetDelay(const base::TimeDelta& last_delay);

  // Helper to calculate the initial value for exponential backoff.
  // See possible values and comments in polling_constants.h.
  virtual base::TimeDelta GetInitialDelay(
      const sessions::ModelNeutralState& state) const;

 protected:
  BackoffDelayProvider(const base::TimeDelta& default_initial_backoff,
                       const base::TimeDelta& short_initial_backoff);

 private:
  const base::TimeDelta default_initial_backoff_;
  const base::TimeDelta short_initial_backoff_;

  DISALLOW_COPY_AND_ASSIGN(BackoffDelayProvider);
};

}  // namespace syncer

#endif  // SYNC_ENGINE_BACKOFF_DELAY_PROVIDER_H_
